summaryrefslogtreecommitdiffstats
path: root/src/collectionfieldsdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/collectionfieldsdialog.h')
-rw-r--r--src/collectionfieldsdialog.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/collectionfieldsdialog.h b/src/collectionfieldsdialog.h
index 7647bec..a3691cc 100644
--- a/src/collectionfieldsdialog.h
+++ b/src/collectionfieldsdialog.h
@@ -57,11 +57,11 @@ public:
/**
* The constructor sets up the dialog.
*
* @param coll A pointer to the collection tqparent of all the attributes
* @param tqparent A pointer to the tqparent widget
* @param name The widget name
*/
- CollectionFieldsDialog(Data::CollPtr coll, TQWidget* tqparent, const char* name=0);
+ CollectionFieldsDialog(Data::CollPtr coll, TQWidget* parent, const char* name=0);
~CollectionFieldsDialog();
signals:
@@ -57,11 +57,11 @@ public:
* The constructor sets up the dialog.
*
- * @param coll A pointer to the collection tqparent of all the attributes
- * @param tqparent A pointer to the tqparent widget
+ * @param coll A pointer to the collection parent of all the attributes
+ * @param parent A pointer to the parent widget
* @param name The widget name
*/